{% raw %}
{% extends "mote/element/index.html" %}
{% load mote_tags %}
{% block codeblock %}
<div class="sg-code-block">
  <h4 class="title">
    Back To Top Button
  </h4>
  <div class="description">
    <p>The back to top component is on every page in the site and is an easy way to get back to the top menu.</p>
  </div>
  <div class="code-example">
      <pre>
          <code class="language-markup">
              <xmp>
                {% render_element element %}
              </xmp>
          </code>
      </pre>
  </div>
</div>
{% endblock %}
{% endraw %}
