<div class="foreground">
    <div class="title">
      <h1>Components</h1>
      <p>Components are UI design pattern elements</p>
    </div>
    <div class="progress">
      <h3>Progress</h3>
      <hr/>
      <p>Production Ready</p>
      <div class="bar ready"></div>
      <p>Needs Refactoring</p>
      <div class="bar refactor"></div>
      <p>Work in Progress</p>
      <div class="bar wip"></div>
      <p>Deprecated</p>
      <div class="bar deprecated"></div>
    </div>
    <div style="clear: both;"></div>
</div>
