
{% extends "base.html" %}
{% load i18n %}

{% block body_class %}default-container{% endblock %}

{% block content %}
<div class="container">
    <div class="title">
        <h3>{% trans "Unable to Login" %}</h3>
    </div>
    <div class="message-notification">
        {% trans "Hi" %}
       <p>{% trans "Sorry, you are having trouble accessing this feature! Due to a temporary technical issue, login and registrations are not available on the Free Basics app for now. To login or register for a profile, visit our free mobisite through your mobile browser at" %} <a href={{ freebasics_url }} target="_blank">{{ freebasics_url }}</a>.{% trans " We're working hard to get this problem resolved. Thank you." %} <br/>
    </div>
</div>
{% endblock %}
 
