.menu-list {
  margin: 0 auto;
  padding: 0 5px;
  display: inline-block;
  position: relative;
  &--search-icon {
    padding: 10px 0;
  }
  &__item {
    display: inline-block;
    border: none;
    padding: 5px 5px 0 0;
    font-size: 13px;
  }
  &__anchor {
    display: inline-block;
    color: #07292F;
    text-transform: uppercase;
    font-weight: bold;
    font-size: 13px;
  }
}
