/*
CORE STYLE OVERIDES
WAGTAIL ADMIN
*/
@import "../utilities/*";
@import "modules/*";

.content-wrapper {
  .pagination {padding: 0 15px;}
  .pagination.col9 {
    width: 100%;
    p {padding: 15px 0 0;}
    ul {padding: 0 45px;}
  }
  .listing {
    &.full-width {
      margin-bottom: 0;
    }
  }
}
//COMMENT TABLE CONTENT
.submit-row .button {
  margin: 0 0 8px 0;
}

//Wagtail Admin - Button
.icon-logout_wrapper {
  display: block;
  padding: 1.7em 1.7em;
  vertical-align: middle;
  &:before {
    content: "";
    background: url("/static/images/icons/logout.svg") 0 0 / contain no-repeat;
    width: 20px;
    height: 20px;
    display: inline-block;
    vertical-align: middle;
    font-weight: bold;
    margin: 0 5px 0 0;
  }
  input[type=submit].icon-logout {
    -webkit-font-smoothing: auto;
    text-decoration: none;
    display: inline-block;
    color: #cacaca;
    padding: 0;
    font-size: 1em;
    font-weight: 400;
    border: none;
    width: auto;
    background: transparent;
    vertical-align: middle;

  }
}

@media screen and (min-width: 90em) {
  .wrapper {
    max-width: 100%;
  }
}
