{% extends "base.html" %}
{% load i18n %}

{% block content %}
  <div class="heading">
    <h1 class="heading__profiles">{% trans "Reset PIN" %}</h1>
  </div>
  <div class="profiles">
  <form method="post" class="profiles__form">
  {% csrf_token %}
      {% if form.errors %}
        <ul class="error-list">
          {% for key, errors in form.errors.items %}
              {% for error in errors %}
                <li class="error-list__item error">{% trans error %}</li>
              {% endfor %}
          {% endfor %}
        </ul>
      {% endif %}

    {{ form.username }}
    {{ form.token }}

    <fieldset>
      <label>{% trans "PIN" %}</label>
      {{ form.password }}
      <span class="input-hint">{% trans "(e.g. 2086)" %}</span>
    </fieldset>

    <fieldset>
      <label>{% trans "Confirm PIN" %}</label>
      {{ form.confirm_password }}
    </fieldset>
      <input type="submit" value='{% trans "Reset PIN" %}' class="call-to-action__button call-to-action__button--primary" />
  </form>
</div>
{% endblock %}
