<div class="section-listing section-listing--general section-listing--general{{self.get_effective_extra_style_hints}}">
{% include "patterns/basics/sections/sectionpage-subsection-list-general.html" %}
{% include "patterns/basics/sections/sectionpage-article-list-general.html" %}
</div>
