# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2017-06-05 14:10
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0018_remove_rendition_filter'),
        ('core', '0060_reaction_questions_index_page'),
    ]

    operations = [
        migrations.AddField(
            model_name='reactionquestionchoice',
            name='success_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
        migrations.AddField(
            model_name='reactionquestionchoice',
            name='success_message',
            field=models.CharField(blank=True, max_length=30, null=True),
        ),
    ]
