{% load wagtailcore_tags core_tags i18n %}
  {% load_tags as tags %}
  <ul class="tag-cloud__block">
  {% for tag in tags %}
    {% if tag %}
      <li class="tag-cloud__item">
        <a href="{% url 'tags_list' tag.slug %}" class="tag-cloud__anchor">
            {{tag.title}}
        </a>
      </li>
      {% endif %}
    {% endfor %}
  </ul>
